==> mmoo_base-1.2.0%2B1.tar.gz: lib/dao/base_dao.dart <==
import 'dart:convert';
import 'dart:io';
import 'dart:math';

import 'package:connectivity/connectivity.dart';
import 'package:crypto/crypto.dart';
import 'package:dio/dio.dart';
import 'package:encrypt/encrypt.dart';
import 'package:mmoo_base/api/address.dart';
import 'package:mmoo_base/api/api.dart';
import 'package:mmoo_base/config/app_config.dart';
import 'package:mmoo_base/config/net_config.dart';
import 'package:mmoo_base/entity/base_entity.dart';
import 'package:mmoo_base/utils/appinfo_util.dart';
import 'package:mmoo_base/utils/code_utils.dart';
import 'package:mmoo_base/utils/common_utils.dart';
import 'package:mmoo_base/utils/navigator_utils.dart';
import 'package:flutter_image_compress/flutter_image_compress.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';
import 'package:path_provider/path_provider.dart';
import 'package:sp_util/sp_util.dart';

import 'dao_result.dart';

class BaseDao {
  static Future<String> getNetWork() async {
    var connectivityResult = await (Connectivity().checkConnectivity());
    if (connectivityResult == ConnectivityResult.mobile) {
      return 'Mobile';
    } else if (connectivityResult == ConnectivityResult.wifi) {
      return 'WIFI';
    } else {
      return '';
    }
  }

  static Future<String> getLocale() async {
    int index = SpUtil.getInt(AppConfig.LOCALE)!;
    switch (index) {
      case 0:
        return 'en';
      case 1:
        return 'de';
      case 2:
        return 'es';
      case 3:
        return 'fr';
      case 4:
        return 'it';
      case 5:
        return 'ja';
      case 6:
        return 'ar';
      default:
        return 'en';
    }
  }

  static Map? requestMap;

  ///基本参数
  static Future<Map> requestParams() async {
    if (requestMap == null) {
      requestMap = {
        'appid': Platform.isAndroid
            ? AppInfoUtil.instance.androidDeviceInfo.androidId
            : Address.appId,
        'appPackage': Address.packageName,
        'channel': Address.channel,
        'from': Platform.isAndroid ? 'android' : 'ios',
        'model': Platform.isAndroid
            ? AppInfoUtil.instance.androidDeviceInfo.model
            : CodeUtils.iosDeviceCode(
            AppInfoUtil.instance.iosDeviceInfo.utsname.machine),
        'os': Platform.isAndroid
            ? AppInfoUtil.instance.androidDeviceInfo.version.release
            : AppInfoUtil.instance.iosDeviceInfo.systemVersion,
        'screen':
        '${(ScreenUtil().screenWidth * ScreenUtil().pixelRatio)
            .round()}x${(ScreenUtil().screenHeight * ScreenUtil().pixelRatio)
            .round()}',
        'version': AppInfoUtil.instance.packageInfo.version,
        'lan': await getLocale(),
        'net': await getNetWork()
      };
    }
    requestMap!['timestamp'] =
        DateTime
            .now()
            .millisecondsSinceEpoch + AppConfig.timeAsync;
    requestMap!['channel'] = Address.channel;
    return requestMap!;
  }

  ///数据封装v1
  static Future<DataResult> fromBaseJson(map, url, {bool token = true}) async {
    if (map is Map) map.addAll(await requestParams());
    if (Address.baseToken.isEmpty != false) {
      Address.baseToken = SpUtil.getString(AppConfig.APP_TOKEN)!;
    }
    var res = await httpManager.netFetch(
        url,
        map is Map ? jsonEncode(map) : map,
        token ? {'Authorization': 'Bearer ${Address.baseToken}'} : null,
        Options(method: 'post'));
    if (res.result && res.data is Map) {
      var baseEntity = BaseEntity().fromJson(res.data);
      try {
        if (baseEntity.time?.isEmpty == false) {
          var t = int.parse(baseEntity.time!);
          if (t != 0) {
            AppConfig.timeAsync = DateTime
                .now()
                .millisecondsSinceEpoch - t;
          }
        }
      } catch (err) {
        AppConfig.printLog(err);
      }
      if (baseEntity.code == '0') {
        return DataResult(baseEntity.data, true, time: baseEntity.time);
      } else {
        if (baseEntity.code == '999' ||
            baseEntity.code == '-1' ||
            baseEntity.code == '1005' ||
            baseEntity.code == '1007' ||
            baseEntity.code == '1010' ||
            baseEntity.code == '1024' ||
            baseEntity.code == '5003' ||
            baseEntity.code == '5017') {
          if (baseEntity.msg!.isEmpty == false) {
            CommonUtils.showToast(baseEntity.msg);
          }
          NavigatorUtils.goGuide2();
        }
        return DataResult(baseEntity, false);
      }
    }
    return DataResult(res, false, dataError: true);
  }

  ///数据加密v2
  static Future<DataResult> fromBaseEncrypt(Map map, url,
      {bool token = true}) async {
    map.addAll(await requestParams());
    String body = jsonEncode(map);
    AppConfig.printLog(body);
    var encodeBody = await encryptToBase64(body, NetConfig.ENCRYPT_DES);
    var time = DateTime
        .now()
        .millisecondsSinceEpoch + AppConfig.timeAsync;
    var nonce = randomSize(6);
    var append = time.toString() + body + NetConfig.ENCRYPT_YANZHI + nonce;
    var convert = Utf8Encoder().convert(append);
    var sign = md5.convert(convert).toString().toUpperCase();
    Map<String, dynamic> header = {
      'x-sign': sign,
      'x-time': time.toString(),
      'x-request-id': nonce
    };
    if (Address.baseToken.isEmpty != false) {
      Address.baseToken = SpUtil.getString(AppConfig.APP_TOKEN)!;
    }
    if (token) {
      header['Authorization'] = 'Bearer ${Address.baseToken}';
    }
    var res = await httpManager.netFetch(
        url, encodeBody, header, Options(method: 'post'));
    if (res.result) {
      if (res.data is Map) {
        var baseEntity = BaseEntity().fromJson(res.data);
        try {
          if (baseEntity.time?.isEmpty == false) {
            var t = int.parse(baseEntity.time!);
            if (t != 0) {
              AppConfig.timeAsync = DateTime
                  .now()
                  .millisecondsSinceEpoch - t;
            }
          }
        } catch (err) {
          AppConfig.printLog(err);
        }
        if (baseEntity.code == '0') {
          return DataResult(baseEntity.data, true, time: baseEntity.time);
        } else {
          if (baseEntity.code == '999' ||
              baseEntity.code == '-1' ||
              baseEntity.code == '1005' ||
              baseEntity.code == '1007' ||
              baseEntity.code == '1010' ||
              baseEntity.code == '5003' ||
              baseEntity.code == '5017') {
            if (baseEntity.msg!.isEmpty == false) {
              CommonUtils.showToast(baseEntity.msg);
            }
            NavigatorUtils.goGuide2();
          }
          return DataResult(baseEntity, false);
        }
      } else {
        try {
          var decryptBody =
          await decryptFromBase64(res.data, NetConfig.DECRYPT_DES);
          AppConfig.printLog(decryptBody);
          var data = jsonDecode(decryptBody);
          var baseEntity = BaseEntity().fromJson(data);
          try {
            if (baseEntity.time?.isEmpty == false) {
              var t = int.parse(baseEntity.time!);
              if (t != 0) {
                AppConfig.timeAsync = DateTime
                    .now()
                    .millisecondsSinceEpoch - t;
              }
            }
          } catch (err) {
            AppConfig.printLog(err);
          }
          var signKey = res.headers['x-sign'][0];
          if (await doCheck(signKey, decryptBody)) {
            if (baseEntity.code == '0') {
              return DataResult(baseEntity.data, true, time: baseEntity.time);
            } else {
              if (baseEntity.code == '999' ||
                  baseEntity.code == '-1' ||
                  baseEntity.code == '1005' ||
                  baseEntity.code == '1007' ||
                  baseEntity.code == '1010' ||
                  baseEntity.code == '1024' ||
                  baseEntity.code == '5003' ||
                  baseEntity.code == '5017') {
                if (baseEntity.msg!.isEmpty == false) {
                  CommonUtils.showToast(baseEntity.msg);
                }
                NavigatorUtils.goGuide2();
              }
              return DataResult(baseEntity, false);
            }
          } else {
            return DataResult(baseEntity, false, dataError: true);
          }
        } catch (e) {
          AppConfig.printLog(e);
          return DataResult(res, false, dataError: true);
        }
      }
    }
    return DataResult(res, false, dataError: true);
  }

  static String sessionId = '';

  ///数据加密v3
  static Future<DataResult> fromBaseEncryptV3(Map map, url,
      {bool post = true, Map<String, dynamic>? queryParameters}) async {
    String body = queryParameters != null
        ? jsonEncode(queryParameters)
        : jsonEncode(map);
    AppConfig.printLog(body);
    var nonce = randomSize(6);
    if (sessionId.isEmpty != false) {
      sessionId = randomSize(8);
    }
    if (Address.baseToken.isEmpty != false) {
      Address.baseToken = SpUtil.getString(AppConfig.APP_TOKEN)!;
    }
    Map<String, dynamic> header = {
      'x-request-id': nonce,
      'x-sessionid': sessionId,
      'Authorization': Address.baseToken
    };
    var encodeBody;
    if (post) {
      encodeBody = await encryptToBase64(body, NetConfig.ENCRYPT_DES);
      var time = DateTime
          .now()
          .millisecondsSinceEpoch + AppConfig.timeAsync;
      var append = time.toString() + body + NetConfig.ENCRYPT_YANZHI + nonce;
      var convert = Utf8Encoder().convert(append);
      var sign = md5.convert(convert).toString().toUpperCase();
      header['x-sign'] = sign;
      header['x-time'] = time.toString();
    }
    var res = await httpManager.netFetch(url, post ? encodeBody : null, header,
        Options(method: post ? 'post' : 'get'),
        queryParameters: !post ? queryParameters : null);
    if (res.result) {
      if (res.data is Map) {
        var baseEntity = BaseEntity().fromJson(res.data);
        try {
          if (baseEntity.time?.isEmpty == false) {
            var t = int.parse(baseEntity.time!);
            if (t != 0) {
              AppConfig.timeAsync = DateTime
                  .now()
                  .millisecondsSinceEpoch - t;
            }
          }
        } catch (err) {
          AppConfig.printLog(err);
        }
        if (baseEntity.code == '0') {
          return DataResult(baseEntity.data, true, time: baseEntity.time);
        } else {
          if (baseEntity.code == '999' ||
              baseEntity.code == '-1' ||
              baseEntity.code == '1005' ||
              baseEntity.code == '1007' ||
              baseEntity.code == '1010' ||
              baseEntity.code == '1024' ||
              baseEntity.code == '5003' ||
              baseEntity.code == '5017') {
            if (baseEntity.msg!.isEmpty == false) {
              CommonUtils.showToast(baseEntity.msg);
            }
            NavigatorUtils.goGuide2();
          }
          return DataResult(baseEntity, false);
        }
      } else {
        try {
          var decryptBody =
          await decryptFromBase64(res.data, NetConfig.DECRYPT_DES);
          AppConfig.printLog(decryptBody);
          var data = jsonDecode(decryptBody);
          var baseEntity = BaseEntity().fromJson(data);
          try {
            if (baseEntity.time?.isEmpty == false) {
              var t = int.parse(baseEntity.time!);
              if (t != 0) {
                AppConfig.timeAsync = DateTime
                    .now()
                    .millisecondsSinceEpoch - t;
              }
            }
          } catch (err) {
            AppConfig.printLog(err);
          }
          var signKey = res.headers['x-sign'][0];
          if (await doCheck(signKey, decryptBody)) {
            if (baseEntity.code == '0') {
              return DataResult(baseEntity.data, true, time: baseEntity.time);
            } else {
              if (baseEntity.code == '999' ||
                  baseEntity.code == '-1' ||
                  baseEntity.code == '1005' ||
                  baseEntity.code == '1007' ||
                  baseEntity.code == '1010' ||
                  baseEntity.code == '1024' ||
                  baseEntity.code == '5003' ||
                  baseEntity.code == '5017') {
                if (baseEntity.msg!.isEmpty == false) {
                  CommonUtils.showToast(baseEntity.msg);
                }
                NavigatorUtils.goGuide2();
              }
              return DataResult(baseEntity, false);
            }
          } else {
            return DataResult(baseEntity, false, dataError: true);
          }
        } catch (e) {
          AppConfig.printLog(e);
          return DataResult(res, false, dataError: true);
        }
      }
    }
    return DataResult(res, false, dataError: true);
  }

  static String randomSize(int size) {
    String str =
        'abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789';
    Random random = Random();
    //指定字符串长度，拼接字符
    String string = '';
    for (int i = 0; i < size; i++) {
      //获取指定长度的字符串中任意一个字符的索引值
      int number = random.nextInt(str.length);
      //根据索引值获取对应的字符
      string += str[number];
    }
    return string;
  }

  ///des加密
  static Future<String> encryptToBase64(String data, String keyStr) async {
    final key = Key.fromUtf8(keyStr);
    final iv = IV.fromLength(16);
    final encrypt = Encrypter(AES(key, mode: AESMode.ecb));
    final encrypted = encrypt.encrypt(data, iv: iv);
    return encrypted.base64;
  }

  static Future<String> decryptFromBase64(String data, String keyStr) async {
    final key = Key.fromUtf8(keyStr);
    final iv = IV.fromLength(16);
    final encrypt = Encrypter(AES(key, mode: AESMode.ecb));
    final decrypted = encrypt.decrypt(Encrypted(base64Decode(data)), iv: iv);
    return decrypted;
  }

  static Future<bool> doCheck(String? signKey, String decryptKey) async {
    var key = base64Decode(NetConfig.DECRYPT_KEY);
    var bytes = utf8.encode(decryptKey);
    var hmacMd5 = Hmac(md5, key); // HMAC-SHA256
    var digest = hmacMd5.convert(bytes);
    return base64Encode(digest.bytes) == signKey;
  }

  static Future<String> compressImage(String image) async {
    File imageFile = File(image);
    int length = imageFile.lengthSync();
    int max = 1024 * 1024 * 2;
    if (length > max) {
      Directory tempDir = await getTemporaryDirectory();
      String targetPath =
          '${tempDir.absolute.path}/Image_Temp_${DateTime
          .now()
          .millisecondsSinceEpoch}.jpg';
      File? result = await (FlutterImageCompress.compressAndGetFile(
          image, targetPath,
          quality: 100 - ((max / length) * 100).round()));
      if ((result?.lengthSync() ?? 0) > max) {
        return compressImage(result!.path);
      }
      return result?.path ?? '';
    } else {
      return image;
    }
  }
}

==> mmoo_base-1.3.0%2B1.tar.gz: lib/dao/base_dao.dart <==
import 'dart:convert';
import 'dart:io';
import 'dart:math';

import 'package:connectivity/connectivity.dart';
import 'package:crypto/crypto.dart';
import 'package:dio/dio.dart';
import 'package:encrypt/encrypt.dart';
import 'package:flutter_image_compress/flutter_image_compress.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';
import 'package:mmoo_base/api/address.dart';
import 'package:mmoo_base/api/api.dart';
import 'package:mmoo_base/config/app_config.dart';
import 'package:mmoo_base/config/net_config.dart';
import 'package:mmoo_base/entity/base_entity.dart';
import 'package:mmoo_base/utils/appinfo_utils.dart';
import 'package:mmoo_base/utils/code_utils.dart';
import 'package:mmoo_base/utils/common_utils.dart';
import 'package:mmoo_base/utils/navigator_utils.dart';
import 'package:path_provider/path_provider.dart';
import 'package:sp_util/sp_util.dart';

import 'dao_result.dart';

class BaseDao {
  static Future<String> getNetWork() async {
    var connectivityResult = await (Connectivity().checkConnectivity());
    if (connectivityResult == ConnectivityResult.mobile) {
      return 'Mobile';
    } else if (connectivityResult == ConnectivityResult.wifi) {
      return 'WIFI';
    } else {
      return '';
    }
  }

  static Future<String> getLocale() async {
    int index = SpUtil.getInt(AppConfig.appLocale)!;
    switch (index) {
      case 0:
        return 'en';
      case 1:
        return 'de';
      case 2:
        return 'es';
      case 3:
        return 'fr';
      case 4:
        return 'it';
      case 5:
        return 'ja';
      case 6:
        return 'ar';
      default:
        return 'en';
    }
  }

  static Map? requestMap;

  ///基本参数
  static Future<Map> requestParams() async {
    requestMap ??= {
      'appid': Platform.isAndroid
          ? AppInfoUtils.instance.androidDeviceInfo.androidId
          : Address.appId,
      'appPackage': Address.packageName,
      'channel': Address.channel,
      'from': Platform.isAndroid ? 'android' : 'ios',
      'model': Platform.isAndroid
          ? AppInfoUtils.instance.androidDeviceInfo.model
          : CodeUtils.iosDeviceCode(
              AppInfoUtils.instance.iosDeviceInfo.utsname.machine),
      'os': Platform.isAndroid
          ? AppInfoUtils.instance.androidDeviceInfo.version.release
          : AppInfoUtils.instance.iosDeviceInfo.systemVersion,
      'screen':
          '${(ScreenUtil().screenWidth * (ScreenUtil().pixelRatio ?? 0)).round()}x${(ScreenUtil().screenHeight * (ScreenUtil().pixelRatio ?? 0)).round()}',
      'version': AppInfoUtils.instance.packageInfo.version,
      'lan': await getLocale(),
      'net': await getNetWork()
    };
    requestMap!['timestamp'] =
        DateTime.now().millisecondsSinceEpoch + AppConfig.timeAsync;
    requestMap!['channel'] = Address.channel;
    return requestMap!;
  }

  ///数据封装v1
  static Future<DataResult> fromBaseJson(map, url, {bool token = true}) async {
    if (map is Map) map.addAll(await requestParams());
    if (Address.baseToken.isEmpty != false) {
      Address.baseToken = SpUtil.getString(AppConfig.appToken)!;
    }
    var res = await httpManager.netFetch(
        url,
        map is Map ? jsonEncode(map) : map,
        token ? {'Authorization': 'Bearer ${Address.baseToken}'} : null,
        Options(method: 'post'));
    if (res.result && res.data is Map) {
      var baseEntity = BaseEntity.fromJson(res.data);
      try {
        if (baseEntity.time?.isEmpty == false) {
          var t = int.parse(baseEntity.time!);
          if (t != 0) {
            AppConfig.timeAsync = DateTime.now().millisecondsSinceEpoch - t;
          }
        }
      } catch (err) {
        AppConfig.printLog(err);
      }
      if (baseEntity.code == '0') {
        return DataResult(baseEntity.data, true, time: baseEntity.time);
      } else {
        if (baseEntity.code == '999' ||
            baseEntity.code == '-1' ||
            baseEntity.code == '1005' ||
            baseEntity.code == '1007' ||
            baseEntity.code == '1010' ||
            baseEntity.code == '1024' ||
            baseEntity.code == '5003' ||
            baseEntity.code == '5017') {
          if (baseEntity.msg!.isEmpty == false) {
            CommonUtils.showToast(baseEntity.msg);
          }
          NavigatorUtils.goGuide2();
        }
        return DataResult(baseEntity, false);
      }
    }
    return DataResult(res, false, dataError: true);
  }

  ///数据加密v2
  static Future<DataResult> fromBaseEncrypt(Map map, url,
      {bool token = true}) async {
    map.addAll(await requestParams());
    String body = jsonEncode(map);
    AppConfig.printLog(body);
    var encodeBody = await encryptToBase64(body, NetConfig.encryptDes);
    var time = DateTime.now().millisecondsSinceEpoch + AppConfig.timeAsync;
    var nonce = randomSize(6);
    var append = time.toString() + body + NetConfig.encryptYanZhi + nonce;
    var convert = const Utf8Encoder().convert(append);
    var sign = md5.convert(convert).toString().toUpperCase();
    Map<String, dynamic> header = {
      'x-sign': sign,
      'x-time': time.toString(),
      'x-request-id': nonce
    };
    if (Address.baseToken.isEmpty != false) {
      Address.baseToken = SpUtil.getString(AppConfig.appToken)!;
    }
    if (token) {
      header['Authorization'] = 'Bearer ${Address.baseToken}';
    }
    var res = await httpManager.netFetch(
        url, encodeBody, header, Options(method: 'post'));
    if (res.result) {
      if (res.data is Map) {
        var baseEntity = BaseEntity.fromJson(res.data);
        try {
          if (baseEntity.time?.isEmpty == false) {
            var t = int.parse(baseEntity.time!);
            if (t != 0) {
              AppConfig.timeAsync = DateTime.now().millisecondsSinceEpoch - t;
            }
          }
        } catch (err) {
          AppConfig.printLog(err);
        }
        if (baseEntity.code == '0') {
          return DataResult(baseEntity.data, true, time: baseEntity.time);
        } else {
          if (baseEntity.code == '999' ||
              baseEntity.code == '-1' ||
              baseEntity.code == '1005' ||
              baseEntity.code == '1007' ||
              baseEntity.code == '1010' ||
              baseEntity.code == '5003' ||
              baseEntity.code == '5017') {
            if (baseEntity.msg!.isEmpty == false) {
              CommonUtils.showToast(baseEntity.msg);
            }
            NavigatorUtils.goGuide2();
          }
          return DataResult(baseEntity, false);
        }
      } else {
        try {
          var decryptBody =
              await decryptFromBase64(res.data, NetConfig.decryptDes);
          AppConfig.printLog(decryptBody);
          var data = jsonDecode(decryptBody);
          var baseEntity = BaseEntity.fromJson(data);
          try {
            if (baseEntity.time?.isEmpty == false) {
              var t = int.parse(baseEntity.time!);
              if (t != 0) {
                AppConfig.timeAsync = DateTime.now().millisecondsSinceEpoch - t;
              }
            }
          } catch (err) {
            AppConfig.printLog(err);
          }
          var signKey = res.headers['x-sign'][0];
          if (await doCheck(signKey, decryptBody)) {
            if (baseEntity.code == '0') {
              return DataResult(baseEntity.data, true, time: baseEntity.time);
            } else {
              if (baseEntity.code == '999' ||
                  baseEntity.code == '-1' ||
                  baseEntity.code == '1005' ||
                  baseEntity.code == '1007' ||
                  baseEntity.code == '1010' ||
                  baseEntity.code == '1024' ||
                  baseEntity.code == '5003' ||
                  baseEntity.code == '5017') {
                if (baseEntity.msg!.isEmpty == false) {
                  CommonUtils.showToast(baseEntity.msg);
                }
                NavigatorUtils.goGuide2();
              }
              return DataResult(baseEntity, false);
            }
          } else {
            return DataResult(baseEntity, false, dataError: true);
          }
        } catch (e) {
          AppConfig.printLog(e);
          return DataResult(res, false, dataError: true);
        }
      }
    }
    return DataResult(res, false, dataError: true);
  }

  static String sessionId = '';

  ///数据加密v3
  static Future<DataResult> fromBaseEncryptV3(Map map, url,
      {bool post = true, Map<String, dynamic>? queryParameters}) async {
    String body =
        queryParameters != null ? jsonEncode(queryParameters) : jsonEncode(map);
    AppConfig.printLog(body);
    var nonce = randomSize(6);
    if (sessionId.isEmpty != false) {
      sessionId = randomSize(8);
    }
    if (Address.baseToken.isEmpty != false) {
      Address.baseToken = SpUtil.getString(AppConfig.appToken)!;
    }
    Map<String, dynamic> header = {
      'x-request-id': nonce,
      'x-sessionid': sessionId,
      'Authorization': Address.baseToken
    };
    dynamic encodeBody;
    if (post) {
      encodeBody = await encryptToBase64(body, NetConfig.encryptDes);
      var time = DateTime.now().millisecondsSinceEpoch + AppConfig.timeAsync;
      var append = time.toString() + body + NetConfig.encryptYanZhi + nonce;
      var convert = const Utf8Encoder().convert(append);
      var sign = md5.convert(convert).toString().toUpperCase();
      header['x-sign'] = sign;
      header['x-time'] = time.toString();
    }
    var res = await httpManager.netFetch(url, post ? encodeBody : null, header,
        Options(method: post ? 'post' : 'get'),
        queryParameters: !post ? queryParameters : null);
    if (res.result) {
      if (res.data is Map) {
        var baseEntity = BaseEntity.fromJson(res.data);
        try {
          if (baseEntity.time?.isEmpty == false) {
            var t = int.parse(baseEntity.time!);
            if (t != 0) {
              AppConfig.timeAsync = DateTime.now().millisecondsSinceEpoch - t;
            }
          }
        } catch (err) {
          AppConfig.printLog(err);
        }
        if (baseEntity.code == '0') {
          return DataResult(baseEntity.data, true, time: baseEntity.time);
        } else {
          if (baseEntity.code == '999' ||
              baseEntity.code == '-1' ||
              baseEntity.code == '1005' ||
              baseEntity.code == '1007' ||
              baseEntity.code == '1010' ||
              baseEntity.code == '1024' ||
              baseEntity.code == '5003' ||
              baseEntity.code == '5017') {
            if (baseEntity.msg!.isEmpty == false) {
              CommonUtils.showToast(baseEntity.msg);
            }
            NavigatorUtils.goGuide2();
          }
          return DataResult(baseEntity, false);
        }
      } else {
        try {
          var decryptBody =
              await decryptFromBase64(res.data, NetConfig.decryptDes);
          AppConfig.printLog(decryptBody);
          var data = jsonDecode(decryptBody);
          var baseEntity = BaseEntity.fromJson(data);
          try {
            if (baseEntity.time?.isEmpty == false) {
              var t = int.parse(baseEntity.time!);
              if (t != 0) {
                AppConfig.timeAsync = DateTime.now().millisecondsSinceEpoch - t;
              }
            }
          } catch (err) {
            AppConfig.printLog(err);
          }
          var signKey = res.headers['x-sign'][0];
          if (await doCheck(signKey, decryptBody)) {
            if (baseEntity.code == '0') {
              return DataResult(baseEntity.data, true, time: baseEntity.time);
            } else {
              if (baseEntity.code == '999' ||
                  baseEntity.code == '-1' ||
                  baseEntity.code == '1005' ||
                  baseEntity.code == '1007' ||
                  baseEntity.code == '1010' ||
                  baseEntity.code == '1024' ||
                  baseEntity.code == '5003' ||
                  baseEntity.code == '5017') {
                if (baseEntity.msg!.isEmpty == false) {
                  CommonUtils.showToast(baseEntity.msg);
                }
                NavigatorUtils.goGuide2();
              }
              return DataResult(baseEntity, false);
            }
          } else {
            return DataResult(baseEntity, false, dataError: true);
          }
        } catch (e) {
          AppConfig.printLog(e);
          return DataResult(res, false, dataError: true);
        }
      }
    }
    return DataResult(res, false, dataError: true);
  }

  static String randomSize(int size) {
    String str =
        'abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789';
    Random random = Random();
    //指定字符串长度，拼接字符
    String string = '';
    for (int i = 0; i < size; i++) {
      //获取指定长度的字符串中任意一个字符的索引值
      int number = random.nextInt(str.length);
      //根据索引值获取对应的字符
      string += str[number];
    }
    return string;
  }

  ///des加密
  static Future<String> encryptToBase64(String data, String keyStr) async {
    final key = Key.fromUtf8(keyStr);
    final iv = IV.fromLength(16);
    final encrypt = Encrypter(AES(key, mode: AESMode.ecb));
    final encrypted = encrypt.encrypt(data, iv: iv);
    return encrypted.base64;
  }

  static Future<String> decryptFromBase64(String data, String keyStr) async {
    final key = Key.fromUtf8(keyStr);
    final iv = IV.fromLength(16);
    final encrypt = Encrypter(AES(key, mode: AESMode.ecb));
    final decrypted = encrypt.decrypt(Encrypted(base64Decode(data)), iv: iv);
    return decrypted;
  }

  static Future<bool> doCheck(String? signKey, String decryptKey) async {
    var key = base64Decode(NetConfig.decryptKey);
    var bytes = utf8.encode(decryptKey);
    var hmacMd5 = Hmac(md5, key); // HMAC-SHA256
    var digest = hmacMd5.convert(bytes);
    return base64Encode(digest.bytes) == signKey;
  }

  static Future<String> compressImage(String image) async {
    File imageFile = File(image);
    int length = imageFile.lengthSync();
    int max = 1024 * 1024 * 2;
    if (length > max) {
      Directory tempDir = await getTemporaryDirectory();
      String targetPath =
          '${tempDir.absolute.path}/Image_Temp_${DateTime.now().millisecondsSinceEpoch}.jpg';
      File? result = await (FlutterImageCompress.compressAndGetFile(
          image, targetPath,
          quality: 100 - ((max / length) * 100).round()));
      if ((result?.lengthSync() ?? 0) > max) {
        return compressImage(result!.path);
      }
      return result?.path ?? '';
    } else {
      return image;
    }
  }
}
